@@ -15,7 +15,7 @@ details.
 
 You should have received a copy of the GNU General Public License along with
 GCC; see the file COPYING.  If not, write to the Free Software
-Foundation, 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.  */
+Foundation, 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301, USA.  */
 
 /* As a special exception, if you link this library with files compiled with
    GCC to produce an executable, this does not cause the resulting executable
@@ -34,13 +34,13 @@ Foundation, 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.  */
 #include <stddef.h>		/* so noone else will get system versions */
 #include <assert.h>
 
-#include <objc/objc.h>		/* core data types */
-#include <objc/objc-api.h>	/* runtime api functions */
+#include "objc.h"		/* core data types */
+#include "objc-api.h"		/* runtime api functions */
 
-#include <objc/thr.h>		/* thread and mutex support */
+#include "thr.h"		/* thread and mutex support */
 
-#include <objc/hash.h>		/* hash structures */
-#include <objc/objc-list.h>	/* linear lists */
+#include "hash.h"		/* hash structures */
+#include "objc-list.h"		/* linear lists */
 
 #ifdef __cplusplus
 extern "C" {
